Document pixel buffer rendering and diffing.
Enums
- Origin
- The origin of a documents page, this is used for comparisons of pages with different dimensions.
Constants
- DEFAULT_
PIXEL_ PER_ PT - The default pixel per pt value used for rendering pages to pixel buffers.
- PPP_
TO_ PPI_ FACTOR - The factor used to convert pixel per pt to pixel per inch.
Functions
- page_
diff - Render the visual diff of two pages. If the pages do not have matching dimensions, then the origin is used to align them, regions without overlap will simply be colored black.
- ppi_
to_ ppp - Converts a pixel-per-inch ratio to a pixel-per-pt ratio.
- ppp_
to_ ppi - Converts a pixel-per-pt ratio to a pixel-per-inch ratio.