page_diff

Function page_diff 

pub fn page_diff(base: &Pixmap, change: &Pixmap, origin: Origin) -> Pixmap
Render the visual diff of two pages. If the pages do not have matching dimensions, then the origin is used to align them, regions without overlap will simply be colored black.

The difference is created by change on top of base using a difference filter.