pub struct Paths { /* private fields */ }Expand description
An object which contains various paths relevant for handling on-disk operations and path transformations.
The paths retruned by this struct are not guaranteed to exist on disk, but if they don’t exist at the given paths, then they don’t exist for a project.
Implementations
Sourceimpl Paths
impl Paths
Sourcepub fn project_root(&self) -> &Path
pub fn project_root(&self) -> &Path
Returns the path to the project root.
The project root is used to resolve absolute paths in typst when executing tests.
Sourcepub fn test_root(&self) -> PathBuf
pub fn test_root(&self) -> PathBuf
Returns the path to the test root. That is the path within the project root where the regression test suite is located.
The test root is used to resolve test identifiers.
Sourcepub fn template(&self) -> PathBuf
pub fn template(&self) -> PathBuf
Returns the path to the test template, that is, the source template to use when generating new tests, not a template test.
Sourcepub fn vcs_root(&self) -> Option<&Path>
pub fn vcs_root(&self) -> Option<&Path>
Returns the absolute canonicalized path to the vcs root. That is the path within which the project may be located.
The vcs root is used for properly handling non-persistent storage of tests.
Sourcepub fn test_dir(&self, id: &Id) -> PathBuf
pub fn test_dir(&self, id: &Id) -> PathBuf
Create a path to the test directory for the given identifier.
Sourcepub fn test_script(&self, id: &Id) -> PathBuf
pub fn test_script(&self, id: &Id) -> PathBuf
Create a path to the test script for the given identifier.
Sourcepub fn test_ref_script(&self, id: &Id) -> PathBuf
pub fn test_ref_script(&self, id: &Id) -> PathBuf
Create a path to the reference script for the given identifier.
Sourcepub fn test_ref_dir(&self, id: &Id) -> PathBuf
pub fn test_ref_dir(&self, id: &Id) -> PathBuf
Create a path to the reference directory for the given identifier.
Sourcepub fn test_out_dir(&self, id: &Id) -> PathBuf
pub fn test_out_dir(&self, id: &Id) -> PathBuf
Create a path to the output directory for the given identifier.
Sourcepub fn test_diff_dir(&self, id: &Id) -> PathBuf
pub fn test_diff_dir(&self, id: &Id) -> PathBuf
Create a path to the difference directory for the given identifier.