Project

Struct Project 

pub struct Project { /* private fields */ }
A fully loaded project, this can be constructed from ShallowProject, which can be used to discover project paths without loading any configuration or manifests.

Implementations

Source

impl Project

pub fn new<P: Into<PathBuf>>(root: P) -> Self

Create a new empty project.

pub fn with_vcs(self, vcs: Option<Vcs>) -> Self

Attach a version control system to this project.

pub fn with_manifest(self, manifest: Option<PackageManifest>) -> Self

Attach a parsed manifest to this project.

pub fn with_config(self, config: ProjectConfig) -> Self

Attach a parsed project config to this project.

pub fn with_unit_test_template(self, unit_test_template: Option<String>) -> Self

Attach a unit test template to this project.

pub fn exists_at(dir: &Path) -> Result<bool>

Checks the given directory for a project root, returning true if it was found.

Source

impl Project

pub fn base(&self) -> &ShallowProject

Returns the shallow base object for this project.

pub fn manifest(&self) -> Option<&PackageManifest>

The fully parsed project manifest.

pub fn package_spec(&self) -> Option<PackageSpec>

A package spec for this package itself, this is used by template tests refer to themselves without attempting to download the package.

pub fn config(&self) -> &ProjectConfig

The fully parsed project config layer.

pub fn unit_test_template(&self) -> Option<&str>

Returns the unit test template, that is, the source template to use when generating new unit tests.

pub fn vcs(&self) -> Option<&Vcs>

Returns the Vcs this project is managed by or None if no supported Vcs was found.

Source

impl Project

pub fn unit_tests_root(&self) -> PathBuf

Returns the path to the test root. That is the path within the project root where the test suite is located.

The test root is used to resolve test identifiers.

pub fn template_root(&self) -> Option<PathBuf>

Returns the root path of the template directory.

pub fn template_entrypoint(&self) -> Option<PathBuf>

Returns the entrypoint script inside the template directory.

pub fn unit_test_template_file(&self) -> PathBuf

Returns the path to the unit test template, that is, the source template to use when generating new unit tests.

pub fn unit_test_dir(&self, id: &Id) -> PathBuf

Create a path to the test directory for the given identifier.

pub fn unit_test_script(&self, id: &Id) -> PathBuf

Create a path to the test script for the given identifier.

pub fn unit_test_ref_script(&self, id: &Id) -> PathBuf

Create a path to the reference script for the given identifier.

pub fn unit_test_ref_dir(&self, id: &Id) -> PathBuf

Create a path to the reference directory for the given identifier.

pub fn unit_test_out_dir(&self, id: &Id) -> PathBuf

Create a path to the output directory for the given identifier.

pub fn unit_test_diff_dir(&self, id: &Id) -> PathBuf

Create a path to the difference directory for the given identifier.

Methods from Deref<Target = ShallowProject>

pub fn parse_manifest(&self) -> Result<Option<PackageManifest>, ManifestError>

Parses the project manifest if it exists. Returns None if no manifest is found.

pub fn parse_config( &self, manifest: &PackageManifest, ) -> Result<Option<ProjectConfig>, ManifestError>

Parses the manifest config from the tool section. Returns None if no tool section found.

pub fn read_unit_test_template( &self, config: &ProjectConfig, ) -> Result<Option<String>, Error>

Reads the project’s unit test template if it exists. Returns None if no template was found.

pub fn root(&self) -> &Path

Returns the path to the project root.

The project root is used to resolve absolute paths in typst when executing tests.

pub fn manifest_file(&self) -> PathBuf

Returns the path to the project manifest (typst.toml).

pub fn vcs_root(&self) -> Option<&Path>

Returns the path to the VCS root.

The VCS root is used for properly handling non-persistent storage of tests.