pub struct ShallowProject { /* private fields */ }Expand description
Represents a “shallow” unloaded project, it contains the base paths required to load a project.
Implementations
Sourceimpl ShallowProject
impl ShallowProject
Sourcepub fn new<P, V>(project: P, vcs: V) -> Self
pub fn new<P, V>(project: P, vcs: V) -> Self
Create a new project with the given roots.
It is recommended to canonicalize them, but it is not strictly necessary.
Sourcepub fn discover<P: AsRef<Path>>(
dir: P,
search_manifest: bool,
) -> Result<Option<Self>, Error>
pub fn discover<P: AsRef<Path>>( dir: P, search_manifest: bool, ) -> Result<Option<Self>, Error>
Attempt to discover various paths for a directory.
If search_manifest is true, then this will attempt to find the
project root by looking for a Typst manifest and return None if no
manifest is found. If it is true, then dir is used as the project
root.
Sourceimpl ShallowProject
impl ShallowProject
Sourcepub fn load(self) -> Result<Project, LoadError>
pub fn load(self) -> Result<Project, LoadError>
Loads the manifest, configuration, and unit test template of a project.
Sourcepub fn parse_manifest(&self) -> Result<Option<PackageManifest>, ManifestError>
pub fn parse_manifest(&self) -> Result<Option<PackageManifest>, ManifestError>
Parses the project manifest if it exists. Returns None if no
manifest is found.
Sourcepub fn parse_config(
&self,
manifest: &PackageManifest,
) -> Result<Option<ProjectConfig>, ManifestError>
pub fn parse_config( &self, manifest: &PackageManifest, ) -> Result<Option<ProjectConfig>, ManifestError>
Parses the manifest config from the tool section. Returns None if no
tool section found.
Sourcepub fn read_unit_test_template(
&self,
config: &ProjectConfig,
) -> Result<Option<String>, Error>
pub fn read_unit_test_template( &self, config: &ProjectConfig, ) -> Result<Option<String>, Error>
Reads the project’s unit test template if it exists. Returns None if
no template was found.
Sourceimpl ShallowProject
impl ShallowProject