Module test

Module test 

Test loading and on-disk manipulation.

Re-exports

pub use self::template::Test as TemplateTest;
pub use self::unit::Test as UnitTest;

Modules

template
unit
Test loading and on-disk manipulation.

Structs

Id
A test id, this is the relative path from the test root directory, down to the folder containing the test script.
TestResult
The result of a single test run.

Enums

Annotation
A test annotation used to configure test specific behavior.
ParseAnnotationError
An error which may occur while parsing an annotation.
ParseIdError
Returned by Id::new and Id::new_from_path.
Stage
The stage of a single test run.
Test
A test within a test suite.