TestResult

Struct TestResult 

pub struct TestResult { /* private fields */ }
The result of a single test run.

Implementations

Source

impl TestResult

pub fn skipped() -> Self

Create a result for a test for a skipped test. This will set the starting time to now, the duration to zero and the result to None.

This can be used for constructing test results in advance to ensure an aborted test run contains a skip result for all yet-to-be-run tests.

pub fn filtered() -> Self

Create a result for a test for a filtered test. This will set the starting time to now, the duration to zero and the result to filtered.

Source

impl TestResult

pub fn stage(&self) -> &Stage

The stage of this rest result, if it was started.

pub fn warnings(&self) -> &[SourceDiagnostic]

The warnings of the test emitted by the compiler.

pub fn timestamp(&self) -> Instant

The timestamp at which the suite run started.

pub fn duration(&self) -> Duration

The duration of the test, this a zero if this test wasn’t started.

pub fn is_skipped(&self) -> bool

Whether the test was not started.

pub fn is_filtered(&self) -> bool

Whether the test was filtered out.

pub fn is_pass(&self) -> bool

Whether the test passed compilation and/or comparison/update.

pub fn is_fail(&self) -> bool

Whether the test failed compilation or comparison.

pub fn errors(&self) -> Option<&[SourceDiagnostic]>

The errors emitted by the compiler if compilation failed.

Source

impl TestResult

pub fn start(&mut self)

Sets the timestamp to Instant::now.

See TestResult::end.

pub fn end(&mut self)

Sets the duration to the time elapsed since TestResult::start was called.

pub fn set_passed_compilation(&mut self)

Sets the kind for this test to a compilation pass.

pub fn set_failed_reference_compilation(&mut self, error: Error)

Sets the kind for this test to a reference compilation failure.

pub fn set_failed_test_compilation(&mut self, error: Error)

Sets the kind for this test to a test compilation failure.

pub fn set_passed_comparison(&mut self)

Sets the kind for this test to a test comparison pass.

pub fn set_failed_comparison(&mut self, error: Error)

Sets the kind for this test to a comparison failure.

pub fn set_updated(&mut self, optimized: bool)

Sets the kind for this test to a test update.

pub fn set_warnings<I>(&mut self, warnings: I)

Sets the warnings for this test.