Test

Struct Test 

pub struct Test { /* private fields */ }
A standalone test script and its associated documents.

Implementations

Source

impl Test

pub fn load(project: &Project, id: Id) -> Result<Option<Test>, LoadError>

Attempt to load a test, returns None if no test could be found.

Source

impl Test

pub fn id(&self) -> &Id

The id of this test.

pub fn kind(&self) -> Kind

The kind of this test.

pub fn annotations(&self) -> &[Annotation]

This test’s annotations.

pub fn is_skip(&self) -> bool

Whether this test has a skip annotation.

Source

impl Test

pub fn create( project: &Project, vcs: Option<&Vcs>, id: Id, source: &str, reference: Option<Reference>, ) -> Result<Test, CreateError>

Creates a new test on disk, the kind is inferred from the passed reference and annotations are parsed from the test script.

Panics

Panics if the given id is equal to the unique template test id.

pub fn create_temporary_directories(&self, project: &Project) -> Result<()>

Creates the temporary directories of this test.

pub fn create_script(&self, project: &Project, source: &str) -> Result<()>

Creates the test script of this test, this will truncate the file if it already exists.

pub fn create_reference_script( &self, project: &Project, source: &str, ) -> Result<()>

Creates reference script of this test, this will truncate the file if it already exists.

pub fn create_reference_document( &self, project: &Project, reference: &Document, optimize_options: Option<&Options>, ) -> Result<(), SaveError>

Creates the persistent reference document of this test.

pub fn delete(&self, project: &Project) -> Result<()>

Deletes all directories and scripts of this test.

pub fn delete_temporary_directories(&self, project: &Project) -> Result<()>

Deletes the temporary directories of this test.

pub fn delete_script(&self, project: &Project) -> Result<()>

Deletes the test script of this test.

pub fn delete_reference_script(&self, project: &Project) -> Result<()>

Deletes reference script of this test.

pub fn delete_reference_document(&self, project: &Project) -> Result<()>

Deletes persistent reference document of this test.

pub fn make_ephemeral( &mut self, project: &Project, vcs: Option<&Vcs>, ) -> Result<()>

Removes any previous references, if they exist and creates a reference script by copying the test script.

pub fn make_persistent( &mut self, project: &Project, vcs: Option<&Vcs>, reference: &Document, optimize_options: Option<&Options>, ) -> Result<(), SaveError>

Removes any previous references, if they exist and creates persistent references from the given pages.

pub fn make_compile_only( &mut self, project: &Project, vcs: Option<&Vcs>, ) -> Result<()>

Removes any previous references, if they exist.

pub fn load_source(&self, project: &Project) -> Result<Source>

Loads the test script source of this test.

pub fn load_reference_source(&self, project: &Project) -> Result<Option<Source>>

Loads the reference test script source of this test, if this test is ephemeral.

pub fn load_document(&self, project: &Project) -> Result<Document, LoadError>

Loads the test document of this test.

pub fn load_reference_document( &self, project: &Project, ) -> Result<Document, LoadError>

Loads the persistent reference document of this test.