pub struct Project { /* private fields */ }Expand description
A fully loaded project, this can be constructed from ShallowProject,
which can be used to discover project paths without loading any
configuration or manifests.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn with_vcs(self, vcs: Option<Vcs>) -> Self
pub fn with_vcs(self, vcs: Option<Vcs>) -> Self
Attach a version control system to this project.
Sourcepub fn with_manifest(self, manifest: Option<PackageManifest>) -> Self
pub fn with_manifest(self, manifest: Option<PackageManifest>) -> Self
Attach a parsed manifest to this project.
Sourcepub fn with_config(self, config: ProjectConfig) -> Self
pub fn with_config(self, config: ProjectConfig) -> Self
Attach a parsed project config to this project.
Sourcepub fn with_unit_test_template(self, unit_test_template: Option<String>) -> Self
pub fn with_unit_test_template(self, unit_test_template: Option<String>) -> Self
Attach a unit test template to this project.
Sourceimpl Project
impl Project
Sourcepub fn base(&self) -> &ShallowProject
pub fn base(&self) -> &ShallowProject
Returns the shallow base object for this project.
Sourcepub fn manifest(&self) -> Option<&PackageManifest>
pub fn manifest(&self) -> Option<&PackageManifest>
The fully parsed project manifest.
Sourcepub fn package_spec(&self) -> Option<PackageSpec>
pub fn package_spec(&self) -> Option<PackageSpec>
A package spec for this package itself, this is used by template tests refer to themselves without attempting to download the package.
Sourcepub fn config(&self) -> &ProjectConfig
pub fn config(&self) -> &ProjectConfig
The fully parsed project config layer.
Sourcepub fn unit_test_template(&self) -> Option<&str>
pub fn unit_test_template(&self) -> Option<&str>
Returns the unit test template, that is, the source template to use when generating new unit tests.
Sourceimpl Project
impl Project
Sourcepub fn unit_tests_root(&self) -> PathBuf
pub fn unit_tests_root(&self) -> PathBuf
Returns the path to the test root. That is the path within the project root where the test suite is located.
The test root is used to resolve test identifiers.
Sourcepub fn template_root(&self) -> Option<PathBuf>
pub fn template_root(&self) -> Option<PathBuf>
Returns the root path of the template directory.
Sourcepub fn template_entrypoint(&self) -> Option<PathBuf>
pub fn template_entrypoint(&self) -> Option<PathBuf>
Returns the entrypoint script inside the template directory.
Sourcepub fn unit_test_template_file(&self) -> PathBuf
pub fn unit_test_template_file(&self) -> PathBuf
Returns the path to the unit test template, that is, the source template to use when generating new unit tests.
Sourcepub fn unit_test_dir(&self, id: &Id) -> PathBuf
pub fn unit_test_dir(&self, id: &Id) -> PathBuf
Create a path to the test directory for the given identifier.
Sourcepub fn unit_test_script(&self, id: &Id) -> PathBuf
pub fn unit_test_script(&self, id: &Id) -> PathBuf
Create a path to the test script for the given identifier.
Sourcepub fn unit_test_ref_script(&self, id: &Id) -> PathBuf
pub fn unit_test_ref_script(&self, id: &Id) -> PathBuf
Create a path to the reference script for the given identifier.
Sourcepub fn unit_test_ref_dir(&self, id: &Id) -> PathBuf
pub fn unit_test_ref_dir(&self, id: &Id) -> PathBuf
Create a path to the reference directory for the given identifier.
Sourcepub fn unit_test_out_dir(&self, id: &Id) -> PathBuf
pub fn unit_test_out_dir(&self, id: &Id) -> PathBuf
Create a path to the output directory for the given identifier.
Sourcepub fn unit_test_diff_dir(&self, id: &Id) -> PathBuf
pub fn unit_test_diff_dir(&self, id: &Id) -> PathBuf
Create a path to the difference directory for the given identifier.
Methods from Deref<Target = ShallowProject>
Sourcepub fn parse_manifest(&self) -> Result<Option<PackageManifest>, ManifestError>
pub fn parse_manifest(&self) -> Result<Option<PackageManifest>, ManifestError>
Parses the project manifest if it exists. Returns None if no
manifest is found.
Sourcepub fn parse_config(
&self,
manifest: &PackageManifest,
) -> Result<Option<ProjectConfig>, ManifestError>
pub fn parse_config( &self, manifest: &PackageManifest, ) -> Result<Option<ProjectConfig>, ManifestError>
Parses the manifest config from the tool section. Returns None if no
tool section found.
Sourcepub fn read_unit_test_template(
&self,
config: &ProjectConfig,
) -> Result<Option<String>, Error>
pub fn read_unit_test_template( &self, config: &ProjectConfig, ) -> Result<Option<String>, Error>
Reads the project’s unit test template if it exists. Returns None if
no template was found.
Sourcepub fn root(&self) -> &Path
pub fn root(&self) -> &Path
Returns the path to the project root.
The project root is used to resolve absolute paths in typst when executing tests.
Sourcepub fn manifest_file(&self) -> PathBuf
pub fn manifest_file(&self) -> PathBuf
Returns the path to the project manifest (typst.toml).