Test loading and on-disk manipulation.
Re-exports
Modules
Structs
- Id
- A test id, this is the relative path from the test root directory, down to the folder containing the test script.
- Test
Result - The result of a single test run.
Enums
- Annotation
- A test annotation used to configure test specific behavior.
- Parse
Annotation Error - An error which may occur while parsing an annotation.
- Parse
IdError - Returned by
Id::newandId::new_from_path. - Stage
- The stage of a single test run.
- Test
- A test within a test suite.