pub struct TestResult { /* private fields */ }Expand description
The result of a single test run.
Implementations
Sourceimpl TestResult
impl TestResult
Sourcepub fn skipped() -> Self
pub fn skipped() -> Self
Create a result for a test for a skipped test. This will set the
starting time to now, the duration to zero and the result to None.
This can be used for constructing test results in advance to ensure an aborted test run contains a skip result for all yet-to-be-run tests.
Sourceimpl TestResult
impl TestResult
Sourcepub fn warnings(&self) -> &[SourceDiagnostic]
pub fn warnings(&self) -> &[SourceDiagnostic]
The warnings of the test emitted by the compiler.
Sourcepub fn duration(&self) -> Duration
pub fn duration(&self) -> Duration
The duration of the test, this a zero if this test wasn’t started.
Sourcepub fn is_skipped(&self) -> bool
pub fn is_skipped(&self) -> bool
Whether the test was not started.
Sourcepub fn is_filtered(&self) -> bool
pub fn is_filtered(&self) -> bool
Whether the test was filtered out.
Sourcepub fn errors(&self) -> Option<&[SourceDiagnostic]>
pub fn errors(&self) -> Option<&[SourceDiagnostic]>
The errors emitted by the compiler if compilation failed.
Sourceimpl TestResult
impl TestResult
Sourcepub fn start(&mut self)
pub fn start(&mut self)
Sets the timestamp to Instant::now.
See TestResult::end.
Sourcepub fn end(&mut self)
pub fn end(&mut self)
Sets the duration to the time elapsed since TestResult::start was
called.
Sourcepub fn set_passed_compilation(&mut self)
pub fn set_passed_compilation(&mut self)
Sets the kind for this test to a compilation pass.
Sourcepub fn set_failed_reference_compilation(&mut self, error: Error)
pub fn set_failed_reference_compilation(&mut self, error: Error)
Sets the kind for this test to a reference compilation failure.
Sourcepub fn set_failed_test_compilation(&mut self, error: Error)
pub fn set_failed_test_compilation(&mut self, error: Error)
Sets the kind for this test to a test compilation failure.
Sourcepub fn set_passed_comparison(&mut self)
pub fn set_passed_comparison(&mut self)
Sets the kind for this test to a test comparison pass.
Sourcepub fn set_failed_comparison(&mut self, error: Error)
pub fn set_failed_comparison(&mut self, error: Error)
Sets the kind for this test to a comparison failure.
Sourcepub fn set_updated(&mut self, optimized: bool)
pub fn set_updated(&mut self, optimized: bool)
Sets the kind for this test to a test update.
Sourcepub fn set_warnings<I>(&mut self, warnings: I)
pub fn set_warnings<I>(&mut self, warnings: I)
Sets the warnings for this test.